%define anolis_release 1
Name:		libpaper
Version:	2.1.1
Release:	%{anolis_release}%{?dist}
Summary:	Library and tools for handling papersize
License:	LGPL-2.1-or-later
URL:		https://github.com/rrthomas/libpaper/
Source0:        https://github.com/rrthomas/libpaper/releases/download/v%{version}/%{name}-%{version}.tar.gz
# Pulled from paper
Source1:	localepaper.c

# gcc is no longer in buildroot by default
BuildRequires:  gcc
# uses make
BuildRequires:  make
Provides:       bundled(gnulib)

%description
The libpaper package enables users to indicate their preferred paper
size and specifies system-wide and per-user paper size catalogues, which can
also be used directly (see paperspecs(5)).

%package devel
Summary:	Headers/Libraries for developing programs that use libpaper
Requires:	%{name} = %{version}-%{release}

%description devel
This package contains headers and libraries that programmers will need
to develop applications which use libpaper.

%package doc
Summary: Documents for %{name}
BuildArch: noarch
Requires: %{name} = %{version}-%{release}

%description  doc
Doc pages for %{name}

%package -n paper
Summary:	Print paper size information
# This is licensed differently from libpaper.
# paper.c is GPL-3.0-or-later
# localepaper.c is FSFAP (except it is missing the warranty disclaimer... but the intent is clear)
License:	GPL-3.0-or-later AND FSFAP

%description -n paper
The paper(1) utility can be used to find the user's preferred
default paper size and give information about known sizes.

%prep
%autosetup -p1
cp %{SOURCE1} src/

%build
%configure --disable-static
%make_build

# localepaper
pushd src
%{__cc} %{optflags} -I.. -Ilibgnu -o localepaper localepaper.c libgnu/.libs/libgnupaper.a
popd

%check
# No upstream tests
echo "Testing localepaper tool"
locale width height > expected
./src/localepaper | tr ' ' "\n" > got
diff -u expected got
# No real way to test the paper tool

%install
%make_install

mkdir -p $RPM_BUILD_ROOT%{_sysconfdir}

mkdir %{buildroot}%{_libexecdir}
install -m0755 src/localepaper %{buildroot}%{_libexecdir}

rm -fr %{buildroot}%{_datadir}/doc/%{name}

%generate_compatibility_deps

%files
%license COPYING
%config(noreplace) %{_sysconfdir}/paperspecs
%{_libdir}/libpaper.so.*
%{abidir}/*.dump
%{_bindir}/paperconf

%files devel
%{_includedir}/paper.h
%{_libdir}/libpaper.so

%files doc
%doc ChangeLog README

%files -n paper
%{_bindir}/paper
%{abidir}/paper-option.list
%{_libexecdir}/localepaper
%{_mandir}/man1/*
%{_mandir}/man5/*

%changelog
* Tue Feb 18 2025 mgb01105731 <mgb01105731@alibaba-inc.com> - 2.1.1-1
- Update to 2.1.1 from 2.1.0

* Sun Apr 16 2023 Funda Wang <fundawang@yeah.net> - 2.1.0-1
- New version 2.1.0

* Mon Mar 27 2023 Yuanhong Peng <yummypeng@linux.alibaba.com> - 2.0.10-1
- Update version 2.0.10

* Tue Feb 14 2023 Funda Wang <fundawang@yeah.net> - 2.0.8-1
- New version 2.0.8

* Mon Jan 23 2023 Funda Wang <fundawang@yeah.net> - 2.0.4-1
- Import package for anolis 23
